__title__ = "fastcrc"
__description__ = "A hyper-fast Python module for computing CRC(16, 32, 64) checksum"
__url__ = "https://github.com/overcat/fastcrc"
__issues__ = f"{__url__}/issues"
__version__ = "0.2.1-dev.2"
__author__ = "overcat"
__author_email__ = "4catcode@gmail.com"
__license__ = "MIT License"



"""
Compute a CRC-32 checksum of data.
"""
from typing import Optional

from .fastcrc import crc_32_aixm as _crc_32_aixm
from .fastcrc import crc_32_autosar as _crc_32_autosar
from .fastcrc import crc_32_base91_d as _crc_32_base91_d
from .fastcrc import crc_32_bzip2 as _crc_32_bzip2
from .fastcrc import crc_32_cd_rom_edc as _crc_32_cd_rom_edc
from .fastcrc import crc_32_cksum as _crc_32_cksum
from .fastcrc import crc_32_iscsi as _crc_32_iscsi
from .fastcrc import crc_32_iso_hdlc as _crc_32_iso_hdlc
from .fastcrc import crc_32_jamcrc as _crc_32_jamcrc
from .fastcrc import crc_32_mpeg_2 as _crc_32_mpeg_2
from .fastcrc import crc_32_xfer as _crc_32_xfer
from .fastcrc import (
    crc_32_reversed_reciprocal_refin as _crc_32_reversed_reciprocal_refin,
)
from .utils import _ensure_bytes

__always_supported = (
    "aixm",
    "autosar",
    "base91_d",
    "bzip2",
    "cd_rom_edc",
    "cksum",
    "iscsi",
    "iso_hdlc",
    "jamcrc",
    "mpeg_2",
    "xfer",
)

algorithms_guaranteed = set(__always_supported)
algorithms_available = set(__always_supported)


def aixm(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the aixm algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_aixm(data, initial)


def autosar(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the autosar algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_autosar(data, initial)


def base91_d(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the base91_d algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_base91_d(data, initial)


def bzip2(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the bzip2 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_bzip2(data, initial)


def cd_rom_edc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the cd_rom_edc algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_cd_rom_edc(data, initial)


def cksum(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the cksum algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_cksum(data, initial)


def iscsi(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the iscsi algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_iscsi(data, initial)


def iso_hdlc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the iso_hdlc algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_iso_hdlc(data, initial)


def jamcrc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the jamcrc algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_jamcrc(data, initial)


def mpeg_2(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the mpeg_2 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_mpeg_2(data, initial)


def xfer(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the xfer algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_xfer(data, initial)


def reversed_reciprocal_refin(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-32 checksum of data with the reversed reciprocal refin algorithm.

    **This method may be removed in the future.**

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_32_reversed_reciprocal_refin(data, initial)



"""
Compute a CRC-16 checksum of data.
"""
from typing import Optional

from .fastcrc import crc_16_arc as _crc_16_arc
from .fastcrc import crc_16_cdma2000 as _crc_16_cdma2000
from .fastcrc import crc_16_cms as _crc_16_cms
from .fastcrc import crc_16_dds_110 as _crc_16_dds_110
from .fastcrc import crc_16_dect_r as _crc_16_dect_r
from .fastcrc import crc_16_dect_x as _crc_16_dect_x
from .fastcrc import crc_16_dnp as _crc_16_dnp
from .fastcrc import crc_16_en_13757 as _crc_16_en_13757
from .fastcrc import crc_16_genibus as _crc_16_genibus
from .fastcrc import crc_16_gsm as _crc_16_gsm
from .fastcrc import crc_16_ibm_3740 as _crc_16_ibm_3740
from .fastcrc import crc_16_ibm_sdlc as _crc_16_ibm_sdlc
from .fastcrc import crc_16_iso_iec_14443_3_a as _crc_16_iso_iec_14443_3_a
from .fastcrc import crc_16_kermit as _crc_16_kermit
from .fastcrc import crc_16_lj1200 as _crc_16_lj1200
from .fastcrc import crc_16_maxim_dow as _crc_16_maxim_dow
from .fastcrc import crc_16_mcrf4xx as _crc_16_mcrf4xx
from .fastcrc import crc_16_modbus as _crc_16_modbus
from .fastcrc import crc_16_nrsc_5 as _crc_16_nrsc_5
from .fastcrc import crc_16_opensafety_a as _crc_16_opensafety_a
from .fastcrc import crc_16_opensafety_b as _crc_16_opensafety_b
from .fastcrc import crc_16_profibus as _crc_16_profibus
from .fastcrc import crc_16_riello as _crc_16_riello
from .fastcrc import crc_16_spi_fujitsu as _crc_16_spi_fujitsu
from .fastcrc import crc_16_t10_dif as _crc_16_t10_dif
from .fastcrc import crc_16_teledisk as _crc_16_teledisk
from .fastcrc import crc_16_tms37157 as _crc_16_tms37157
from .fastcrc import crc_16_umts as _crc_16_umts
from .fastcrc import crc_16_usb as _crc_16_usb
from .fastcrc import crc_16_xmodem as _crc_16_xmodem
from .fastcrc import crc_16_ibm_refin as _crc_16_ibm_refin
from .utils import _ensure_bytes

__always_supported = (
    "arc",
    "cdma2000",
    "cms",
    "dds_110",
    "dect_r",
    "dect_x",
    "dnp",
    "en_13757",
    "genibus",
    "gsm",
    "ibm_3740",
    "ibm_sdlc",
    "iso_iec_14443_3_a",
    "kermit",
    "lj1200",
    "maxim_dow",
    "mcrf4xx",
    "modbus",
    "nrsc_5",
    "opensafety_a",
    "opensafety_b",
    "profibus",
    "riello",
    "spi_fujitsu",
    "t10_dif",
    "teledisk",
    "tms37157",
    "umts",
    "usb",
    "xmodem",
)

algorithms_guaranteed = set(__always_supported)
algorithms_available = set(__always_supported)


def arc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the arc algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_arc(data, initial)


def cdma2000(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the cdma2000 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_cdma2000(data, initial)


def cms(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the cms algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_cms(data, initial)


def dds_110(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the dds_110 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_dds_110(data, initial)


def dect_r(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the dect_r algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_dect_r(data, initial)


def dect_x(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the dect_x algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_dect_x(data, initial)


def dnp(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the dnp algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_dnp(data, initial)


def en_13757(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the en_13757 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_en_13757(data, initial)


def genibus(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the genibus algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_genibus(data, initial)


def gsm(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the gsm algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_gsm(data, initial)


def ibm_3740(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the ibm_3740 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_ibm_3740(data, initial)


def ibm_sdlc(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the ibm_sdlc algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_ibm_sdlc(data, initial)


def iso_iec_14443_3_a(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the iso_iec_14443_3_a algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_iso_iec_14443_3_a(data, initial)


def kermit(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the kermit algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_kermit(data, initial)


def lj1200(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the lj1200 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_lj1200(data, initial)


def maxim_dow(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the maxim_dow algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_maxim_dow(data, initial)


def mcrf4xx(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the mcrf4xx algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_mcrf4xx(data, initial)


def modbus(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the modbus algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_modbus(data, initial)


def nrsc_5(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the nrsc_5 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_nrsc_5(data, initial)


def opensafety_a(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the opensafety_a algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_opensafety_a(data, initial)


def opensafety_b(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the opensafety_b algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_opensafety_b(data, initial)


def profibus(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the profibus algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_profibus(data, initial)


def riello(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the riello algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_riello(data, initial)


def spi_fujitsu(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the spi_fujitsu algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_spi_fujitsu(data, initial)


def t10_dif(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the t10_dif algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_t10_dif(data, initial)


def teledisk(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the teledisk algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_teledisk(data, initial)


def tms37157(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the tms37157 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_tms37157(data, initial)


def umts(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the umts algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_umts(data, initial)


def usb(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the usb algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_usb(data, initial)


def xmodem(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the xmodem algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_xmodem(data, initial)


def ibm_refin(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-16 checksum of data with the ibm refin algorithm.

    **This method may be removed in the future.**

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_16_ibm_refin(data, initial)



"""
Compute a CRC-64 checksum of data.
"""
from typing import Optional

from .fastcrc import crc_64_ecma_182 as _crc_64_ecma_182
from .fastcrc import crc_64_go_iso as _crc_64_go_iso
from .fastcrc import crc_64_we as _crc_64_we
from .fastcrc import crc_64_xz as _crc_64_xz
from .utils import _ensure_bytes

__always_supported = ("ecma_182", "go_iso", "we", "xz")

algorithms_guaranteed = set(__always_supported)
algorithms_available = set(__always_supported)


def ecma_182(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the ecma_182 algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_64_ecma_182(data, initial)


def go_iso(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the go_iso algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_64_go_iso(data, initial)


def we(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the we algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_64_we(data, initial)


def xz(data: bytes, initial: Optional[int] = None) -> int:
    """
    Compute a CRC-64 checksum of data with the xz algorithm.

    :param bytes data: The data to be computed
    :param Optional[int] initial: The optional starting value of the checksum
    :return: The checksum
    :rtype: int
    :raises TypeError: if the data is not a bytes-like object
    """
    _ensure_bytes(data)
    return _crc_64_xz(data, initial)



def _ensure_bytes(data: bytes) -> None:
    if not isinstance(data, bytes):
        raise TypeError(
            "a bytes-like object is required, not '{data_type}'".format(
                data_type=type(data).__name__
            )
        )



import unittest

from fastcrc import crc16, crc32, crc64

data = b"123456789"
data_part1 = b"1234"
data_part2 = b"56789"


class TestCrc16(unittest.TestCase):
    def test_arc(self):
        self.assertEqual(47933, crc16.arc(data))

    def test_arc_init(self):
        self.assertEqual(47933, crc16.arc(data_part2, crc16.arc(data_part1)))

    def test_cdma2000(self):
        self.assertEqual(19462, crc16.cdma2000(data))

    def test_cdma2000_init(self):
        self.assertEqual(19462, crc16.cdma2000(data_part2, crc16.cdma2000(data_part1)))

    def test_cms(self):
        self.assertEqual(44775, crc16.cms(data))

    def test_cms_init(self):
        self.assertEqual(44775, crc16.cms(data_part2, crc16.cms(data_part1)))

    def test_dds_110(self):
        self.assertEqual(40655, crc16.dds_110(data))

    def test_dds_110_init(self):
        self.assertEqual(40655, crc16.dds_110(data_part2, crc16.dds_110(data_part1)))

    def test_dect_r(self):
        self.assertEqual(126, crc16.dect_r(data))

    def test_dect_r_init(self):
        self.assertEqual(126, crc16.dect_r(data_part2, crc16.dect_r(data_part1)))

    def test_dect_x(self):
        self.assertEqual(127, crc16.dect_x(data))

    def test_dect_x_init(self):
        self.assertEqual(127, crc16.dect_x(data_part2, crc16.dect_x(data_part1)))

    def test_dnp(self):
        self.assertEqual(60034, crc16.dnp(data))

    def test_dnp_init(self):
        self.assertEqual(60034, crc16.dnp(data_part2, crc16.dnp(data_part1)))

    def test_en_13757(self):
        self.assertEqual(49847, crc16.en_13757(data))

    def test_en_13757_init(self):
        self.assertEqual(49847, crc16.en_13757(data_part2, crc16.en_13757(data_part1)))

    def test_genibus(self):
        self.assertEqual(54862, crc16.genibus(data))

    def test_genibus_init(self):
        self.assertEqual(54862, crc16.genibus(data_part2, crc16.genibus(data_part1)))

    def test_gsm(self):
        self.assertEqual(52796, crc16.gsm(data))

    def test_gsm_init(self):
        self.assertEqual(52796, crc16.gsm(data_part2, crc16.gsm(data_part1)))

    def test_ibm_3740(self):
        self.assertEqual(10673, crc16.ibm_3740(data))

    def test_ibm_3740_init(self):
        self.assertEqual(10673, crc16.ibm_3740(data_part2, crc16.ibm_3740(data_part1)))

    def test_ibm_sdlc(self):
        self.assertEqual(36974, crc16.ibm_sdlc(data))

    def test_ibm_sdlc_init(self):
        self.assertEqual(36974, crc16.ibm_sdlc(data_part2, crc16.ibm_sdlc(data_part1)))

    def test_iso_iec_14443_3_a(self):
        self.assertEqual(48901, crc16.iso_iec_14443_3_a(data))

    def test_iso_iec_14443_3_a_init(self):
        self.assertEqual(
            48901,
            crc16.iso_iec_14443_3_a(data_part2, crc16.iso_iec_14443_3_a(data_part1)),
        )

    def test_kermit(self):
        self.assertEqual(8585, crc16.kermit(data))

    def test_kermit_init(self):
        self.assertEqual(8585, crc16.kermit(data_part2, crc16.kermit(data_part1)))

    def test_lj1200(self):
        self.assertEqual(48628, crc16.lj1200(data))

    def test_lj1200_init(self):
        self.assertEqual(48628, crc16.lj1200(data_part2, crc16.lj1200(data_part1)))

    def test_maxim_dow(self):
        self.assertEqual(17602, crc16.maxim_dow(data))

    def test_maxim_dow_init(self):
        self.assertEqual(
            17602, crc16.maxim_dow(data_part2, crc16.maxim_dow(data_part1))
        )

    def test_mcrf4xx(self):
        self.assertEqual(28561, crc16.mcrf4xx(data))

    def test_mcrf4xx_init(self):
        self.assertEqual(28561, crc16.mcrf4xx(data_part2, crc16.mcrf4xx(data_part1)))

    def test_modbus(self):
        self.assertEqual(19255, crc16.modbus(data))

    def test_modbus_init(self):
        self.assertEqual(19255, crc16.modbus(data_part2, crc16.modbus(data_part1)))

    def test_nrsc_5(self):
        self.assertEqual(41062, crc16.nrsc_5(data))

    def test_nrsc_5_init(self):
        self.assertEqual(41062, crc16.nrsc_5(data_part2, crc16.nrsc_5(data_part1)))

    def test_opensafety_a(self):
        self.assertEqual(23864, crc16.opensafety_a(data))

    def test_opensafety_a_init(self):
        self.assertEqual(
            23864, crc16.opensafety_a(data_part2, crc16.opensafety_a(data_part1))
        )

    def test_opensafety_b(self):
        self.assertEqual(8446, crc16.opensafety_b(data))

    def test_opensafety_b_init(self):
        self.assertEqual(
            8446, crc16.opensafety_b(data_part2, crc16.opensafety_b(data_part1))
        )

    def test_profibus(self):
        self.assertEqual(43033, crc16.profibus(data))

    def test_profibus_init(self):
        self.assertEqual(43033, crc16.profibus(data_part2, crc16.profibus(data_part1)))

    def test_riello(self):
        self.assertEqual(25552, crc16.riello(data))

    def test_riello_init(self):
        self.assertEqual(25552, crc16.riello(data_part2, crc16.riello(data_part1)))

    def test_spi_fujitsu(self):
        self.assertEqual(58828, crc16.spi_fujitsu(data))

    def test_spi_fujitsu_init(self):
        self.assertEqual(
            58828, crc16.spi_fujitsu(data_part2, crc16.spi_fujitsu(data_part1))
        )

    def test_t10_dif(self):
        self.assertEqual(53467, crc16.t10_dif(data))

    def test_t10_dif_init(self):
        self.assertEqual(53467, crc16.t10_dif(data_part2, crc16.t10_dif(data_part1)))

    def test_teledisk(self):
        self.assertEqual(4019, crc16.teledisk(data))

    def test_teledisk_init(self):
        self.assertEqual(4019, crc16.teledisk(data_part2, crc16.teledisk(data_part1)))

    def test_tms37157(self):
        self.assertEqual(9905, crc16.tms37157(data))

    def test_tms37157_init(self):
        self.assertEqual(9905, crc16.tms37157(data_part2, crc16.tms37157(data_part1)))

    def test_umts(self):
        self.assertEqual(65256, crc16.umts(data))

    def test_umts_init(self):
        self.assertEqual(65256, crc16.umts(data_part2, crc16.umts(data_part1)))

    def test_usb(self):
        self.assertEqual(46280, crc16.usb(data))

    def test_usb_init(self):
        self.assertEqual(46280, crc16.usb(data_part2, crc16.usb(data_part1)))

    def test_xmodem(self):
        self.assertEqual(12739, crc16.xmodem(data))

    def test_xmodem_init(self):
        self.assertEqual(12739, crc16.xmodem(data_part2, crc16.xmodem(data_part1)))

    def test_ibm_refin(self):
        self.assertEqual(15568, crc16.ibm_refin(data))

    def test_ibm_refin_init(self):
        self.assertEqual(
            15568, crc16.ibm_refin(data_part2, crc16.ibm_refin(data_part1))
        )


class TestCrc32(unittest.TestCase):
    def test_aixm(self):
        self.assertEqual(806403967, crc32.aixm(data))

    def test_aixm_init(self):
        self.assertEqual(806403967, crc32.aixm(data_part2, crc32.aixm(data_part1)))

    def test_autosar(self):
        self.assertEqual(379048042, crc32.autosar(data))

    def test_autosar_init(self):
        self.assertEqual(
            379048042, crc32.autosar(data_part2, crc32.autosar(data_part1))
        )

    def test_base91_d(self):
        self.assertEqual(2268157302, crc32.base91_d(data))

    def test_base91_d_init(self):
        self.assertEqual(
            2268157302, crc32.base91_d(data_part2, crc32.base91_d(data_part1))
        )

    def test_bzip2(self):
        self.assertEqual(4236843288, crc32.bzip2(data))

    def test_bzip2_init(self):
        self.assertEqual(4236843288, crc32.bzip2(data_part2, crc32.bzip2(data_part1)))

    def test_cd_rom_edc(self):
        self.assertEqual(1858268612, crc32.cd_rom_edc(data))

    def test_cd_rom_edc_init(self):
        self.assertEqual(
            1858268612, crc32.cd_rom_edc(data_part2, crc32.cd_rom_edc(data_part1))
        )

    def test_cksum(self):
        self.assertEqual(1985902208, crc32.cksum(data))

    def test_cksum_init(self):
        self.assertEqual(1985902208, crc32.cksum(data_part2, crc32.cksum(data_part1)))

    def test_iscsi(self):
        self.assertEqual(3808858755, crc32.iscsi(data))

    def test_iscsi_init(self):
        self.assertEqual(3808858755, crc32.iscsi(data_part2, crc32.iscsi(data_part1)))

    def test_iso_hdlc(self):
        self.assertEqual(3421780262, crc32.iso_hdlc(data))

    def test_iso_hdlc_init(self):
        self.assertEqual(
            3421780262, crc32.iso_hdlc(data_part2, crc32.iso_hdlc(data_part1))
        )

    def test_jamcrc(self):
        self.assertEqual(873187033, crc32.jamcrc(data))

    def test_jamcrc_init(self):
        self.assertEqual(873187033, crc32.jamcrc(data_part2, crc32.jamcrc(data_part1)))

    def test_mpeg_2(self):
        self.assertEqual(58124007, crc32.mpeg_2(data))

    def test_mpeg_2_init(self):
        self.assertEqual(58124007, crc32.mpeg_2(data_part2, crc32.mpeg_2(data_part1)))

    def test_xfer(self):
        self.assertEqual(3171672888, crc32.xfer(data))

    def test_xfer_init(self):
        self.assertEqual(3171672888, crc32.xfer(data_part2, crc32.xfer(data_part1)))

    def test_reversed_reciprocal_refin(self):
        self.assertEqual(
            1239285113,
            crc32.reversed_reciprocal_refin(data),
        )

    def test_reversed_reciprocal_refin_init(self):
        self.assertEqual(
            1239285113,
            crc32.reversed_reciprocal_refin(
                data_part2, crc32.reversed_reciprocal_refin(data_part1)
            ),
        )


class TestCrc64(unittest.TestCase):
    def test_ecma_182(self):
        self.assertEqual(7800480153909949255, crc64.ecma_182(data))

    def test_ecma_182_init(self):
        self.assertEqual(
            7800480153909949255, crc64.ecma_182(data_part2, crc64.ecma_182(data_part1))
        )

    def test_go_iso(self):
        self.assertEqual(13333283586479230977, crc64.go_iso(data))

    def test_go_iso_init(self):
        self.assertEqual(
            13333283586479230977, crc64.go_iso(data_part2, crc64.go_iso(data_part1))
        )

    def test_we(self):
        self.assertEqual(7128171145767219210, crc64.we(data))

    def test_we_init(self):
        self.assertEqual(
            7128171145767219210, crc64.we(data_part2, crc64.we(data_part1))
        )

    def test_xz(self):
        self.assertEqual(11051210869376104954, crc64.xz(data))

    def test_xz_init(self):
        self.assertEqual(
            11051210869376104954, crc64.xz(data_part2, crc64.xz(data_part1))
        )


if __name__ == "__main__":
    unittest.main()



import os

from setuptools import setup
from setuptools_rust import Binding, RustExtension

here = os.path.abspath(os.path.dirname(__file__))

about = {}
with open(
    os.path.join(here, "fastcrc", "__info__.py"), mode="r", encoding="utf-8"
) as f:
    exec(f.read(), about)

with open("README.rst", mode="r", encoding="utf-8") as f:
    readme = f.read()

setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__description__"],
    long_description=readme,
    author=about["__author__"],
    author_email=about["__author_email__"],
    url=about["__url__"],
    license=about["__license__"],
    rust_extensions=[RustExtension("fastcrc.fastcrc", binding=Binding.PyO3)],
    packages=["fastcrc"],
    include_package_data=True,
    package_data={"fastcrc": ["py.typed"]},
    # rust extensions are not zip safe, just like C-extensions.
    zip_safe=False,
    keywords=["crc", "crc16", "crc32", "crc64"],
    project_urls={
        "Code": "https://github.com/overcat/fastcrc",
        "Issue tracker": "https://github.com/overcat/fastcrc/issues",
    },
    python_requires=">=3.6.0",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python",
        "Programming Language :: Rust",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Typing :: Typed",
    ],
)
